==> kubernetes-model-node-5.10.0-sources.jar: io/fabric8/kubernetes/api/model/node/v1beta1/RuntimeClassFluentImpl.java <==
package io.fabric8.kubernetes.api.model.node.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class RuntimeClassFluentImpl<A extends io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent<A>{
  public RuntimeClassFluentImpl() {
  }
  public RuntimeClassFluentImpl(io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClass instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withHandler(instance.getHandler()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withOverhead(instance.getOverhead()); 
    this.withScheduling(instance.getScheduling()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String handler;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder overhead;
  private io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder scheduling;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getHandler() {
    return this.handler;
  }
  public A withHandler(java.lang.String handler) {
    this.handler=handler; return (A) this;
  }
  public java.lang.Boolean hasHandler() {
    return this.handler != null;
  }
  
  /**
   * Method is deprecated. use withHandler instead.
   */
  @java.lang.Deprecated
  public A withNewHandler(java.lang.String arg0) {
    return (A)withHandler(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildOverhead instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.node.v1beta1.Overhead getOverhead() {
    return this.overhead!=null?this.overhead.build():null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.Overhead buildOverhead() {
    return this.overhead!=null?this.overhead.build():null;
  }
  public A withOverhead(io.fabric8.kubernetes.api.model.node.v1beta1.Overhead overhead) {
    _visitables.get("overhead").remove(this.overhead);
    if (overhead!=null){ this.overhead= new io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder(overhead); _visitables.get("overhead").add(this.overhead);} return (A) this;
  }
  public java.lang.Boolean hasOverhead() {
    return this.overhead != null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> withNewOverhead() {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.OverheadNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> withNewOverheadLike(io.fabric8.kubernetes.api.model.node.v1beta1.Overhead item) {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.OverheadNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> editOverhead() {
    return withNewOverheadLike(getOverhead());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> editOrNewOverhead() {
    return withNewOverheadLike(getOverhead() != null ? getOverhead(): new io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> editOrNewOverheadLike(io.fabric8.kubernetes.api.model.node.v1beta1.Overhead item) {
    return withNewOverheadLike(getOverhead() != null ? getOverhead(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildScheduling instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling getScheduling() {
    return this.scheduling!=null?this.scheduling.build():null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling buildScheduling() {
    return this.scheduling!=null?this.scheduling.build():null;
  }
  public A withScheduling(io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling scheduling) {
    _visitables.get("scheduling").remove(this.scheduling);
    if (scheduling!=null){ this.scheduling= new io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder(scheduling); _visitables.get("scheduling").add(this.scheduling);} return (A) this;
  }
  public java.lang.Boolean hasScheduling() {
    return this.scheduling != null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> withNewScheduling() {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.SchedulingNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> withNewSchedulingLike(io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling item) {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.SchedulingNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> editScheduling() {
    return withNewSchedulingLike(getScheduling());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> editOrNewScheduling() {
    return withNewSchedulingLike(getScheduling() != null ? getScheduling(): new io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> editOrNewSchedulingLike(io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling item) {
    return withNewSchedulingLike(getScheduling() != null ? getScheduling(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RuntimeClassFluentImpl that = (RuntimeClassFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (handler != null ? !handler.equals(that.handler) :that.handler != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (overhead != null ? !overhead.equals(that.overhead) :that.overhead != null) return false;
    if (scheduling != null ? !scheduling.equals(that.scheduling) :that.scheduling != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  handler,  kind,  metadata,  overhead,  scheduling,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) RuntimeClassFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class OverheadNestedImpl<N> extends io.fabric8.kubernetes.api.model.node.v1beta1.OverheadFluentImpl<io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<N>> implements io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    OverheadNestedImpl(io.fabric8.kubernetes.api.model.node.v1beta1.Overhead item) {
      this.builder = new io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder(this, item);
    }
    OverheadNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder(this);
    }
    io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder builder;
    public N and() {
      return (N) RuntimeClassFluentImpl.this.withOverhead(builder.build());
    }
    public N endOverhead() {
      return and();
    }
    
  }
  public class SchedulingNestedImpl<N> extends io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingFluentImpl<io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<N>> implements io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SchedulingNestedImpl(io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling item) {
      this.builder = new io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder(this, item);
    }
    SchedulingNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder(this);
    }
    io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder builder;
    public N and() {
      return (N) RuntimeClassFluentImpl.this.withScheduling(builder.build());
    }
    public N endScheduling() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-node-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/node/v1beta1/RuntimeClassFluentImpl.java <==
package io.fabric8.kubernetes.api.model.node.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class RuntimeClassFluentImpl<A extends io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent<A>{
  public RuntimeClassFluentImpl() {
  }
  public RuntimeClassFluentImpl(io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClass instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withHandler(instance.getHandler()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withOverhead(instance.getOverhead()); 
    this.withScheduling(instance.getScheduling()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String handler;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder overhead;
  private io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder scheduling;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getHandler() {
    return this.handler;
  }
  public A withHandler(java.lang.String handler) {
    this.handler=handler; return (A) this;
  }
  public java.lang.Boolean hasHandler() {
    return this.handler != null;
  }
  
  /**
   * Method is deprecated. use withHandler instead.
   */
  @java.lang.Deprecated
  public A withNewHandler(java.lang.String arg0) {
    return (A)withHandler(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildOverhead instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.node.v1beta1.Overhead getOverhead() {
    return this.overhead!=null?this.overhead.build():null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.Overhead buildOverhead() {
    return this.overhead!=null?this.overhead.build():null;
  }
  public A withOverhead(io.fabric8.kubernetes.api.model.node.v1beta1.Overhead overhead) {
    _visitables.get("overhead").remove(this.overhead);
    if (overhead!=null){ this.overhead= new io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder(overhead); _visitables.get("overhead").add(this.overhead);} return (A) this;
  }
  public java.lang.Boolean hasOverhead() {
    return this.overhead != null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> withNewOverhead() {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.OverheadNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> withNewOverheadLike(io.fabric8.kubernetes.api.model.node.v1beta1.Overhead item) {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.OverheadNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> editOverhead() {
    return withNewOverheadLike(getOverhead());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> editOrNewOverhead() {
    return withNewOverheadLike(getOverhead() != null ? getOverhead(): new io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<A> editOrNewOverheadLike(io.fabric8.kubernetes.api.model.node.v1beta1.Overhead item) {
    return withNewOverheadLike(getOverhead() != null ? getOverhead(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildScheduling instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling getScheduling() {
    return this.scheduling!=null?this.scheduling.build():null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling buildScheduling() {
    return this.scheduling!=null?this.scheduling.build():null;
  }
  public A withScheduling(io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling scheduling) {
    _visitables.get("scheduling").remove(this.scheduling);
    if (scheduling!=null){ this.scheduling= new io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder(scheduling); _visitables.get("scheduling").add(this.scheduling);} return (A) this;
  }
  public java.lang.Boolean hasScheduling() {
    return this.scheduling != null;
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> withNewScheduling() {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.SchedulingNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> withNewSchedulingLike(io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling item) {
    return new io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluentImpl.SchedulingNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> editScheduling() {
    return withNewSchedulingLike(getScheduling());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> editOrNewScheduling() {
    return withNewSchedulingLike(getScheduling() != null ? getScheduling(): new io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<A> editOrNewSchedulingLike(io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling item) {
    return withNewSchedulingLike(getScheduling() != null ? getScheduling(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RuntimeClassFluentImpl that = (RuntimeClassFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (handler != null ? !handler.equals(that.handler) :that.handler != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (overhead != null ? !overhead.equals(that.overhead) :that.overhead != null) return false;
    if (scheduling != null ? !scheduling.equals(that.scheduling) :that.scheduling != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  handler,  kind,  metadata,  overhead,  scheduling,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) RuntimeClassFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class OverheadNestedImpl<N> extends io.fabric8.kubernetes.api.model.node.v1beta1.OverheadFluentImpl<io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<N>> implements io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.OverheadNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    OverheadNestedImpl(io.fabric8.kubernetes.api.model.node.v1beta1.Overhead item) {
      this.builder = new io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder(this, item);
    }
    OverheadNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder(this);
    }
    io.fabric8.kubernetes.api.model.node.v1beta1.OverheadBuilder builder;
    public N and() {
      return (N) RuntimeClassFluentImpl.this.withOverhead(builder.build());
    }
    public N endOverhead() {
      return and();
    }
    
  }
  public class SchedulingNestedImpl<N> extends io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingFluentImpl<io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<N>> implements io.fabric8.kubernetes.api.model.node.v1beta1.RuntimeClassFluent.SchedulingNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SchedulingNestedImpl(io.fabric8.kubernetes.api.model.node.v1beta1.Scheduling item) {
      this.builder = new io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder(this, item);
    }
    SchedulingNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder(this);
    }
    io.fabric8.kubernetes.api.model.node.v1beta1.SchedulingBuilder builder;
    public N and() {
      return (N) RuntimeClassFluentImpl.this.withScheduling(builder.build());
    }
    public N endScheduling() {
      return and();
    }
    
  }
  
}
